@@ -9,8 +9,11 @@ def load_config(filename):
         return yaml.safe_load(f)
 
 
-def add_prod_table(production_dir, prod_file='productions.rst',
-                   lstmcpipe_repo_prod_config_url='https://github.com/cta-observatory/lstmcpipe/tree/master/production_configs/'):
+def add_prod_table(
+    production_dir,
+    prod_file='productions.rst',
+    lstmcpipe_repo_prod_config_url='https://github.com/cta-observatory/lstmcpipe/tree/master/production_configs/',
+):
     """
 
     Parameters
@@ -19,6 +22,7 @@ def add_prod_table(production_dir, prod_file='productions.rst',
         path to the production configs directory
     prod_file: str
         RST prod file to update
+    lstmcpipe_repo_prod_config_url: str
     """
 
     prod_txt = '\n'
@@ -31,19 +35,22 @@ def add_prod_table(production_dir, prod_file='productions.rst',
         yml_list = [f for f in prod_dir.iterdir() if f.name.endswith('.yml')]
         if yml_list:
             try:
-               conf = load_config(yml_list[0])
-               prod_id = conf['prod_id']
-            except:
+                conf = load_config(yml_list[0])
+                prod_id = conf['prod_id']
+            except:  # noqa
                 print(f"Could not load prod id for {prod_dir.name}")
                 prod_id = ''
         else:
             print(f"No yml file in {prod_dir}")
 
-        prod_list.append([commit.authored_datetime.ctime(),
-                          f"`{prod_dir.name} <{lstmcpipe_repo_prod_config_url+prod_dir.name}>`_",
-                          prod_id]
-                         )
-        commit_times.append(commit.authored_datetime.ctime())
+        prod_list.append(
+            [
+                commit.authored_datetime.ctime(),
+                f"`{prod_dir.name} <{lstmcpipe_repo_prod_config_url+prod_dir.name}>`_",
+                prod_id,
+            ]
+        )
+        commit_times.append(commit.authored_datetime)
 
     sorted_lists = sorted(zip(commit_times, prod_list))
     prod_list = [prod for _, prod in sorted_lists]
@@ -54,7 +61,6 @@ def add_prod_table(production_dir, prod_file='productions.rst',
         f.write(prod_txt)
 
 
-
 if __name__ == '__main__':
     root_dir = Path(__file__).parent.joinpath('..').resolve()
     prod_dir = root_dir.joinpath('production_configs')
