@@ -1,5 +1,6 @@
 from .mc_process_dl1 import r0_to_dl1, reprocess_dl1, batch_process_dl1
-from .mc_merge_and_copy_dl1 import merge_dl1, batch_merge_and_copy_dl1
+from .mc_train_test_splitting import batch_train_test_splitting, train_test_split
+from .mc_merge_dl1 import merge_dl1, batch_merge_dl1
 from .mc_train import train_pipe, batch_train_pipe, batch_plot_rf_features
 from .mc_dl1_to_dl2 import dl1_to_dl2, batch_dl1_to_dl2
 from .mc_dl2_to_irfs import dl2_to_irfs, batch_dl2_to_irfs
@@ -9,8 +10,10 @@ __all__ = [
     "r0_to_dl1",
     "reprocess_dl1",
     "batch_process_dl1",
+    "batch_train_test_splitting",
+    "train_test_split",
     "merge_dl1",
-    "batch_merge_and_copy_dl1",
+    "batch_merge_dl1",
     "train_pipe",
     "batch_train_pipe",
     "batch_plot_rf_features",
